@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__title__ = 'djangorestframework-jwt-4'
-__version__ = '1.12.0'
-__author__ = 'José Padilla'
+__title__ = 'djangorestframework-jwt-5'
+__version__ = '1.13.0'
+__author__ = 'Jose Padilla'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2014-2017 Blimp LLC'
 
